@@ -11,6 +11,6 @@ loadModule("GloveFitter", TRUE)
   # Runs when attached to search() path such as by library() or require()
   if (interactive()) {
     packageStartupMessage("text2vec is under active development - API can be changed.
-                          \nFor more examples see http://dsnotes.com/categories.html#text2vec-ref")
+                          \nFor more examples see http://dsnotes.com/tags/text2vec/")
   }
 }
